#ifndef _CIPHERS_H
#define _CIPHERS_H
#include "cipher_chaos.h"
#include "cipher_sub.h"


#ifndef CIPHER_COUNT
#define CIPHER_COUNT 3
#endif


int (*(ciphers[CIPHER_COUNT]))()={
	cipher_chaos,
	cipher_sub,
	NULL
};

char *ciphers_name[CIPHER_COUNT]={ 		/* These must be lower-cased */
	"chaos",
	"subst",
	NULL
};


#endif
